.. _guides:

==============
 SymPy Guides
==============

The SymPy Guide discusses common developer process required to get started,
and contributing to the SymPy project. It includes sections on installation, developer
setup, but also common code and documentation style guides. It also covers topic areas
on booleans and the core assumptions module.

For a deeper and elaborate exploration of other SymPy topics, see the
section :ref:`Explanation <explanation>` and the :ref:`API reference <reference>` for
a module break down.

.. toctree::
   :maxdepth: 2

   getting_started/index.rst
   contributing/index.rst
   assumptions.rst
   booleans.rst
